<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="120px"
      class="l-mes"
    >
      <el-form-item label="零件号" prop="partNo">
        <el-input v-model="dataForm.partNo" placeholder="零件号">
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openPartDialog()"
          ></el-button>
        </el-input>
      </el-form-item>
      <el-form-item label="零件名称" prop="partName">
        <el-input v-model="dataForm.partName" placeholder="零件名称"></el-input>
      </el-form-item>
      <el-form-item label="SN号" prop="partBatchNo">
        <el-input v-model="dataForm.partBatchNo" placeholder="SN号"></el-input>
      </el-form-item>
      <!--      <el-form-item label="IFS批次号" prop="ifsBatchNo">-->
      <!--        <el-input-->
      <!--          v-model="dataForm.ifsBatchNo"-->
      <!--          placeholder="IFS批次号"-->
      <!--        ></el-input>-->
      <!--      </el-form-item>-->
      <el-form-item label="库位号" prop="locationNo">
        <el-input v-model="dataForm.locationNo" placeholder="库位号" readonly>
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openLocationDialog()"
          ></el-button>
        </el-input>
      </el-form-item>
      <el-form-item label="库存数量" prop="stockQuantity">
        <el-input
          v-model="dataForm.stockQuantity"
          placeholder="库存数量"
        ></el-input>
      </el-form-item>
      <el-form-item label="是否工序库存" prop="operationStockStatus">
        <el-select
          v-model="dataForm.operationStockStatus"
          filterable
          placeholder="请选择"
          style="width: 100%"
        >
          <el-option
            v-for="item in operationStockStatusOptions"
            :key="item.value"
            :label="item.label"
            :value="item.value"
          >
          </el-option>
        </el-select>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <part-dialog
      :currshowlist.sync="showPart"
      @listenToPartEvent="selectPart"
    />
    <locationDialog
      :currshowlist.sync="showLocation"
      @listenToLocationEvent="selectLocation"
    />
  </el-dialog>
</template>

<script>
import locationDialog from '@/views/common/location.vue'
import PartDialog from '@/views/common/part'
import { addObj } from '../../../api/warehouse/stock'
import { checkSn } from '../../../api/product/personboard'
import { remote } from '@/api/admin/dict'
export default {
  data() {
    return {
      showPart: false,
      showLocation: false,
      visible: false,
      dataForm: {
        id: 0,
        partId: '',
        partNo: '',
        locationNo: '',
        partBatchNo: '',
        locationId: '',
        stockQuantity: '',
        reserveQuantity: '',
        availableStockQuantity: '',
        createTime: '',
        updateTime: '',
        createUser: '',
        updateUser: '',
        status: '',
        ifsBatchNo: null,
        operationStockStatus: false,
        manualInput: true
      },
      dataRule: {
        partNo: [
          { required: true, message: '零件id不能为空', trigger: 'blur' }
        ],
        partBatchNo: [
          { required: true, message: 'SN号不能为空', trigger: 'blur' }
        ],
        // ifsBatchNo: [
        //   { required: true, message: 'IFS批次号不能为空', trigger: 'blur' }
        // ],
        locationNo: [
          { required: true, message: '库位号不能为空', trigger: 'blur' }
        ],
        stockQuantity: [
          { required: true, message: '库存数量不能为空', trigger: 'blur' }
        ],
        operationStockStatus: [
          { required: true, message: '请选择是否工序库存', trigger: 'blur' }
        ]
      },
      isSubmit: false,
      operationStockStatusOptions: []
    }
  },
  components: {
    locationDialog,
    PartDialog
  },
  created() {
    this.getOperationStockStatusOptions()
  },
  methods: {
    getOperationStockStatusOptions() {
      /* remote('operation_stock_type').then((response) => {
        if (response.data.code === 0) {
          this.operationStockStatusOptions = response.data.data
        } else {
          this.operationStockStatusOptions = []
        }
      }) */
      this.operationStockStatusOptions = [
        { value: true, label: '是' },
        { value: false, label: '否' }
      ]
    },
    init(param) {
      this.initStock()
      this.$nextTick(() => {
        this.dataForm.partNo = param.partNo
        this.dataForm.partId = param.partId
        this.dataForm.partName = param.partName
        this.dataForm.locationNo = param.locationNo
        this.dataForm.locationId = param.locationId
        this.dataForm.partBatchNo = param.partBatchNo
        this.visible = true
      })
    },
    openPartDialog() {
      this.showPart = true
    },
    selectPart(param) {
      if (param) {
        this.dataForm.partName = param.partName
        this.dataForm.partNo = param.partNo
        this.dataForm.partId = param.id
        this.$refs.dataForm.validateField('partNo', (valid) => {})
      }
    },
    initStock() {
      this.dataForm.partNo = null
      this.dataForm.partId = null
      this.dataForm.partName = null
      this.dataForm.locationNo = null
      this.dataForm.locationId = null
      this.dataForm.partBatchNo = null
      this.dataForm.ifsBatchNo = null
      this.dataForm.operationStockStatus = false
    },
    openLocationDialog() {
      this.showLocation = true
    },
    selectLocation(param) {
      if (param) {
        this.dataForm.locationNo = param.locNo
        this.dataForm.locationId = param.id
        this.$refs.dataForm.validateField('locationNo', (valid) => {})
      }
    },
    // confirmSubmit() {
    //   this.$confirm('是否同步IFS?', '确认', {
    //     confirmButtonText: '同步',
    //     cancelButtonText: '不同步',
    //     type: 'warning',
    //     showClose: false
    //   })
    //     .then(() => {
    //       this.dataForm.synIfs = true
    //       this.dataFormSubmit()
    //     })
    //     .catch(() => {
    //       this.dataForm.synIfs = false
    //       this.dataFormSubmit()
    //     })
    // },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          // 校验SN重复
          checkSn(this.dataForm)
            .then((res) => {
              this.$confirm('是否同步ERP?', '确认', {
                confirmButtonText: '同步',
                cancelButtonText: '不同步',
                type: 'warning',
                showClose: false,
                closeOnPressEscape: false,
                closeOnClickModal: false
              })
                .then(() => {
                  this.dataForm.synIfs = true
                  addObj(this.dataForm)
                    .then((data) => {
                      this.$message.success('添加成功')
                      this.visible = false
                      this.isSubmit = false
                      this.$emit('refreshDataList')
                    })
                    .catch(() => {
                      this.isSubmit = false
                    })
                })
                .catch(() => {
                  this.dataForm.synIfs = false
                  addObj(this.dataForm)
                    .then((data) => {
                      this.$message.success('添加成功')
                      this.visible = false
                      this.isSubmit = false
                      this.$emit('refreshDataList')
                    })
                    .catch(() => {
                      this.isSubmit = false
                    })
                })
            })
            .catch(() => {
              this.isSubmit = false
            })
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
